==> haskell-http-client-0.4.30-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.4.30
id: http-client-0.4.30-7UAKy49G2o5IiADbR7KQYH
key: http-client-0.4.30-7UAKy49G2o5IiADbR7KQYH
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine, intended as a base layer for more user-friendly packages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.MultipartFormData
    Network.HTTP.Client.Internal
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.PublicSuffixList.Lookup
                Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure
abi: 62f9c3c7dd2a0ef63485eea7366e2c32
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-client-0.4.30
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-client-0.4.30
data-dir: /usr/share/arm-linux-ghc-8.0.1/http-client-0.4.30
hs-libraries: HShttp-client-0.4.30-7UAKy49G2o5IiADbR7KQYH
depends:
    array-0.5.1.1 base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.6-I0Jt0nwhqya3cOqVnbSTZ9 containers-0.5.7.1
    cookie-0.4.2-9rHTsgNPvKoHDPvx7iVkqH
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu deepseq-1.4.2.0
    exceptions-0.8.2.1-BH4VJoBlnhODiEIhn43wEf filepath-1.4.1.0
    ghc-prim-0.5.0.0 http-types-0.9.1-COSfHHdOet5Sq6KAE7lWN
    mime-types-0.1.0.7-1TVT7pakOnO6kciNbLYizr
    network-2.6.2.1-Li0aefQhyJzUSpQ0fLiXL
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    random-1.1-54KmMHXjttlERYcr1mvsAe
    streaming-commons-0.1.15.5-En1wshFTQl13cuLMoYsaBc
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-0.5.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.5.1
id: http-client-0.5.1-G6JInODrrFKFmOa5N5Xoq9
key: http-client-0.5.1-G6JInODrrFKFmOa5N5Xoq9
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.MultipartFormData
    Network.HTTP.Client.Internal
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.PublicSuffixList.Lookup
                Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure
abi: 4338dc0c95c15716362b39fc517e5ad0
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-client-0.5.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-client-0.5.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/http-client-0.5.1
hs-libraries: HShttp-client-0.5.1-G6JInODrrFKFmOa5N5Xoq9
depends:
    array-0.5.1.1 base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.6-I0Jt0nwhqya3cOqVnbSTZ9 containers-0.5.7.1
    cookie-0.4.2.1-DnnDAS5t2oj6QKbT9Eh839 deepseq-1.4.2.0
    exceptions-0.8.2.1-BH4VJoBlnhODiEIhn43wEf filepath-1.4.1.0
    ghc-prim-0.5.0.0 http-types-0.9.1-COSfHHdOet5Sq6KAE7lWN
    mime-types-0.1.0.7-1TVT7pakOnO6kciNbLYizr
    network-2.6.2.1-Li0aefQhyJzUSpQ0fLiXL
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    random-1.1-54KmMHXjttlERYcr1mvsAe
    streaming-commons-0.1.15.5-En1wshFTQl13cuLMoYsaBc
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
